@@ -21,7 +21,15 @@
 __author__ = 'Ramon Bartl <ramon.bartl@inquant.de>'
 __docformat__ = 'plaintext'
 
+import logging
+
+PACKAGENAME = "collective.logbook"
+
+LOGGER = logging.getLogger(PACKAGENAME)
+
 # 0 - all errors get saved in the log
+#     (WARNING: this might cause an NotifyTraceback event flooding)
+#
 # 1 - references existing errors
 REFERENCE_ERRORS = 1
 
@@ -29,4 +37,10 @@ REFERENCE_ERRORS = 1
 STORAGE_KEY = "LOGBOOK"
 INDEX_KEY = "REFINDEX"
 
+# Logbook properties
+PROP_KEY_LOG_ENABLED = 'logbook_enabled'
+PROP_KEY_LOG_MAILS = 'logbook_log_mails'
+PROP_KEY_LARGE_SITE = 'logbook_large_site'
+
+
 # vim: set ft=python ts=4 sw=4 expandtab :
